@echo off
rem *******************************************************************************
rem Licensed Materials - Property of IBM
rem (c) Copyright IBM Corporation 2008, 2013. All Rights Reserved.
rem 
rem Note to U.S. Government Users Restricted Rights:  
rem Use, duplication or disclosure restricted by GSA ADP Schedule 
rem Contract with IBM Corp. 
rem *******************************************************************************

set START_DIR=%~dp0

rem The following four environment variables are used to point to the
rem appropriate JDBC jar file supplied by the database vendor.  For Oracle and
rem SQL Server, the environment variable should point to the driver file itself;
rem for db2i and db2z, the variable should point to the directory that contains
rem the multiple necessary jdbc driver files required on those platforms (for example, 
rem c:\Program Files\IBM\SQLLIB\java\). For DB2, the use of DB2_ABSPATH is optional; 
rem if not set, the default driver installed with the server will be used.

rem Users should set these variables; if they are set, the script will respect
rem their value.  If they are unset, we try locating the driver files in a
rem directory under <JazzInstallDir>/server.  (For example, the default location
rem for the Oracle JDBC driver is under
rem <JazzInstallDir>/server/oracle/ojdbc6.jar).

rem Do not use double quotes when you define your environment variable.  If
rem you're setting it from the command line, do:
rem set ORACLE_JDBC_DRIVER_FILE=c:\path name\ojdbc6.jar
rem not:
rem set ORACLE_JDBC_DRIVER_FILE="c:\path name\ojdbc6.jar"

if NOT "%ORACLE_JDBC_DRIVER_FILE%"=="" goto :after_oracle
set ORACLE_JDBC_DRIVER_FILE=%START_DIR%\oracle\ojdbc6.jar
:after_oracle

if NOT "%SQLSERVER_JDBC_DRIVER_FILE%"=="" goto :after_sqlserver
set SQLSERVER_JDBC_DRIVER_FILE=%START_DIR%\sqlserver\sqljdbc4.jar
:after_sqlserver

if "%DB2I_ABSPATH%"=="" goto :default_db2i
set DB2I_JDBC=%DB2I_ABSPATH%
goto :after_db2i
:default_db2i
set DB2I_JDBC=%START_DIR%\db2i
:after_db2i

if "%DB2Z_ABSPATH%"=="" goto :default_db2z
set DB2Z_JDBC=%DB2Z_ABSPATH%
goto :after_db2z
:default_db2z
set DB2Z_JDBC=%START_DIR%\db2z
:after_db2z

set COGNOS_SDK=%START_DIR%\CognosSDK

rem Convert the current working directory
rem to a format that is valid for use in a
rem a file URL
set CUR_PATH=%cd%
set DRIVE=%cd:~0,1%
set SHORT_PATH=%~sp0%
set SHORT_PATH=%SHORT_PATH:\=/%
set PATH_URL=%DRIVE%%%3a%SHORT_PATH%

setlocal
set JAVA_OPTS=%JAVA_OPTS% -Djava.awt.headless=true
set JAVA_OPTS=%JAVA_OPTS% -DSQLSERVER_JDBC_DRIVER_FILE="%SQLSERVER_JDBC_DRIVER_FILE%"
set JAVA_OPTS=%JAVA_OPTS% -DORACLE_JDBC_DRIVER_FILE="%ORACLE_JDBC_DRIVER_FILE%"
set JAVA_OPTS=%JAVA_OPTS% -DDB2I_JDBC="%DB2I_JDBC%"
set JAVA_OPTS=%JAVA_OPTS% -DDB2Z_JDBC="%DB2Z_JDBC%"
if "%DB2_ABSPATH%"=="" goto :after_db2
set JAVA_OPTS=%JAVA_OPTS% -DDB2_ABSPATH="%DB2_ABSPATH%/"
:after_db2
set JAVA_OPTS=%JAVA_OPTS% -Dorg.eclipse.emf.ecore.plugin.EcorePlugin.doNotLoadResourcesPlugin=true
set JAVA_OPTS=%JAVA_OPTS% -Dorg.apache.tomcat.util.buf.UDecoder.ALLOW_ENCODED_SLASH=true
set JAVA_OPTS=%JAVA_OPTS% -Dorg.apache.catalina.connector.CoyoteAdapter.ALLOW_BACKSLASH=true
set JAVA_OPTS=%JAVA_OPTS% -DJAZZ_HOME=file:///%PATH_URL%conf
set JAVA_OPTS=%JAVA_OPTS% -Dcom.ibm.team.repository.tempDir="%TEMP%"
set JAVA_OPTS=%JAVA_OPTS% -Djazz.connector.sslProtocol=SSL_TLS
set JAVA_OPTS=%JAVA_OPTS% -Djazz.connector.algorithm=IbmX509
set JAVA_OPTS=%JAVA_OPTS% -Xmx1200M
set JAVA_OPTS=%JAVA_OPTS% -Xms1200M
set JAVA_OPTS=%JAVA_OPTS% -Xmn300M
set JAVA_OPTS=%JAVA_OPTS% -XX:MaxDirectMemorySize=1G
set JAVA_OPTS=%JAVA_OPTS% -Xgcpolicy:gencon
rem set JAVA_OPTS=%JAVA_OPTS% -Xcompressedrefs -Xgc:preferredHeapBase=0x100000000
set JAVA_OPTS=%JAVA_OPTS% -Dlog4j.configuration=file:///%PATH_URL%conf/startup_log4j.properties

rem *** Debug service properties ***

rem Give access to restricted areas to the specified list of users.  "*" means all JazzAdmins.
rem See docs for additional properties for allowing restricted access to individual restricted areas.
rem set JAVA_OPTS=%JAVA_OPTS% -Dcom.ibm.team.repository.debug.restricted.authorizedUsers=*

rem Disable the entire debug service.
rem set JAVA_OPTS=%JAVA_OPTS% -Dcom.ibm.team.repository.debug.disabled=true

rem Required for CLM Monitoring
rem set JAVA_OPTS=%JAVA_OPTS% -Dcom.sun.management.jmxremote=true
rem set JAVA_OPTS=%JAVA_OPTS% -Dcom.sun.management.jmxremote.port=1099
rem set JAVA_OPTS=%JAVA_OPTS% -Dcom.sun.management.jmxremote.ssl=false
rem set JAVA_OPTS=%JAVA_OPTS% -Dcom.sun.management.jmxremote.authenticate=false

rem Unset JAVA_HOME because we really want to use the JRE that is bundled.
rem Also, Tomcat will complain if JAVA_HOME is set to a JRE instead of a JDK
rem and that should be avoided
set JAVA_HOME=

set JRE_HOME=%cd%\jre
set CATALINA_HOME=%cd%\tomcat

if ""%1"" == ""-debug"" (
	call "%CATALINA_HOME%"\bin\catalina.bat jpda run
) else (
	call "%CATALINA_HOME%"\bin\startup.bat
)

endlocal
